@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: hostlist.c 1150 2008-01-29 17:35:48Z grondo $
+ *  $Id: hostlist.c 1165 2008-08-07 00:07:31Z grondo $
  *****************************************************************************
- *  $LSDId: hostlist.c 6837 2008-01-29 17:28:09Z grondo $
+ *  $LSDId: hostlist.c 7685 2008-08-07 00:05:52Z grondo $
  *****************************************************************************
  *  Copyright (C) 2002 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -908,22 +908,48 @@ static hostrange_t hostrange_intersect(hostrange_t h1, hostrange_t h2)
  */
 static int hostrange_hn_within(hostrange_t hr, hostname_t hn)
 {
-    int retval = 0;
-
-    if (hr->singlehost && (strcmp(hn->hostname, hr->prefix) == 0))
-        return 1;
-
-    if (strcmp(hr->prefix, hn->prefix) == 0) {
-        if (!hostname_suffix_is_valid(hn)) {
-            if (hr->singlehost)
-                retval = 1;
-        } else if (hn->num <= hr->hi && hn->num >= hr->lo) {
-            int width = hostname_suffix_width(hn);
-            int num = hn->num;
-            retval = _width_equiv(hr->lo, &hr->width, num, &width);
-        }
+    if (hr->singlehost) {
+        /*  
+         *  If the current hostrange [hr] is a `singlehost' (no valid 
+         *   numeric suffix (lo and hi)), then the hostrange [hr]
+         *   stores just one host with name == hr->prefix.
+         *  
+         *  Thus the full hostname in [hn] must match hr->prefix, in
+         *   which case we return true. Otherwise, there is no 
+         *   possibility that [hn] matches [hr].
+         */
+        if (strcmp (hn->hostname, hr->prefix) == 0)
+            return 1;
+        else 
+            return 0;
     }
-    return retval;
+
+    /*
+     *  Now we know [hr] is not a "singlehost", so hostname
+     *   better have a valid numeric suffix, or there is no 
+     *   way we can match
+     */
+    if (!hostname_suffix_is_valid (hn))
+        return 0;
+
+    /*
+     *  If hostrange and hostname prefixes don't match, then
+     *   there is no way the hostname falls within the range [hr].
+     */
+    if (strcmp(hr->prefix, hn->prefix) != 0) 
+        return 0;
+
+    /*
+     *  Finally, check whether [hn], with a valid numeric suffix,
+     *   falls within the range of [hr].
+     */
+    if (hn->num <= hr->hi && hn->num >= hr->lo) {
+        int width = hostname_suffix_width(hn);
+        int num = hn->num;
+        return (_width_equiv(hr->lo, &hr->width, num, &width));
+    }
+
+    return 0;
 }
 
 
@@ -1838,8 +1864,8 @@ int hostlist_delete_nth(hostlist_t hl, int n)
     }
 
   done:
-    UNLOCK_HOSTLIST(hl);
     hl->nhosts--;
+    UNLOCK_HOSTLIST(hl);
     return 1;
 }
 
