@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: slurm.c 1009 2006-02-14 16:11:43Z grondo $
+ *  $Id: slurm.c 1131 2007-06-20 18:02:25Z grondo $
  *****************************************************************************
- *  Copyright (C) 2001-2006 The Regents of the University of California.
+ *  Copyright (C) 2001-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Mark Grondona <mgrondona@llnl.gov>.
  *  UCRL-CODE-2003-005.
@@ -33,9 +33,6 @@
 #include <string.h>
 #include <assert.h>
 
-#include <slurm/slurm.h>
-#include <slurm/slurm_errno.h>
-
 #include "src/common/hostlist.h"
 #include "src/common/split.h"
 #include "src/common/err.h"
@@ -46,6 +43,13 @@
 #include "src/pdsh/mod.h"
 #include "src/pdsh/opt.h"
 
+/*
+ * SLURM headers need to be included after pdsh header files to
+ *  avoid possibly conflicts with the definition of "bool"
+ */
+#include <slurm/slurm.h>
+#include <slurm/slurm_errno.h>
+
 #if STATIC_MODULES
 #  define pdsh_module_info slurm_module_info
 #  define pdsh_module_priority slurm_module_priority
@@ -86,7 +90,8 @@ struct pdsh_module_operations slurm_module_ops = {
  */
 struct pdsh_module_option slurm_module_options[] = 
  { 
-   { 'j', "jobid", "Run on nodes allocated to SLURM job.",
+   { 'j', "jobid,...", 
+     "Run on nodes allocated to SLURM job(s) (\"all\" = all jobs)",
      DSH | PCP, (optFunc) slurm_process_opt
    },
    PDSH_OPT_TABLE_END
@@ -113,26 +118,6 @@ static int mod_slurm_init (void)
     return (0);
 }
 
-/*
- *  Split comma-separated "attrs" from str and append to list `lp'
- */
-static List _list_append (List l, char *str)
-{
-    List tmp = list_split (",", str);
-    ListIterator i = NULL;
-    char *attr = NULL;
-
-    if (l == NULL)
-        return ((l = tmp));
-
-    i = list_iterator_create (tmp);
-    while ((attr = list_next (i)))
-        list_append (l, Strdup(attr));
-    list_destroy (tmp);
-
-    return (l);
-}
-
 
 static int32_t str2jobid (char *str)
 {
@@ -156,7 +141,7 @@ slurm_process_opt(opt_t *pdsh_opts, int opt, char *arg)
 {
     switch (opt) {
     case 'j':
-        job_list = _list_append (job_list, Strdup(arg));
+        job_list = list_split_append (job_list, ",", arg);
         break;
     default:
         break;
@@ -200,36 +185,76 @@ static int _find_id (char *jobid, uint32_t *id)
     return (*id == str2jobid (jobid));
 }
 
+static int _find_str (char *jobid, char *str)
+{
+    return (strcmp (jobid, str) == 0);
+}
+
+/*
+ * Return non-zero if jobid is in list of ids requested by user
+ */
+static int _jobid_requested (List l, uint32_t jobid)
+{
+    if (l == NULL)
+        return (0);
+    return (list_delete_all (l, (ListFindF)_find_id, &jobid));
+}
+
+static int _alljobids_requested (List l)
+{
+    char *all = "all";
+    if (l == NULL)
+        return (0);
+    return (list_delete_all (l, (ListFindF)_find_str, all));
+}
+
+static hostlist_t _hl_append (hostlist_t hl, char *nodes)
+{
+    if (hl == NULL)
+        return (hostlist_create (nodes));
+    else
+        hostlist_push (hl, nodes);
+    return (hl);
+}
+
 static hostlist_t _slurm_wcoll (List joblist)
 {
     int i;
     hostlist_t hl = NULL;
     job_info_msg_t * msg;
-    int32_t jobid = 0;
+    int32_t envjobid = 0;
+    int alljobids = 0;
 
-    if ((joblist == NULL) && (jobid = _slurm_jobid()) < 0)
+    if ((joblist == NULL) && (envjobid = _slurm_jobid()) < 0)
         return (NULL);
 
     if (slurm_load_jobs((time_t) NULL, &msg, 1) < 0) 
         errx ("Unable to contact slurm controller: %s\n", 
               slurm_strerror (errno));
 
+    /*
+     *  Check for "all" in joblist
+     */
+    alljobids = _alljobids_requested (joblist);
+
     for (i = 0; i < msg->record_count; i++) {
         job_info_t *j = &msg->job_array[i];
 
-        if (!joblist && (j->job_id == jobid)) {
+        if (alljobids)
+            hl = _hl_append (hl, j->nodes);
+        else if (!joblist && (j->job_id == envjobid)) {
+            /*
+             *  Only use SLURM_JOBID environment variable if user
+             *   didn't override with -j option
+             */
             hl = hostlist_create (j->nodes);
             break;
         }
-        
-        if ( joblist 
-           && list_delete_all (joblist, (ListFindF)_find_id, &j->job_id)) {
-
-            if (!hl)
-                hl = hostlist_create (j->nodes);
-            else
-                hostlist_push (hl, j->nodes);
-
+        else if (_jobid_requested (joblist, j->job_id)) {
+            hl = _hl_append (hl, j->nodes);
+            /* 
+             * Exit when there is no more jobids to search
+             */
             if (list_count (joblist) == 0)
                 break;
         }
