@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: sshcmd.c 1143 2007-10-23 23:34:58Z grondo $
+ *  $Id: sshcmd.c 1178 2009-03-24 21:46:02Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -254,10 +254,6 @@ sshcmd_destroy (pipecmd_t p)
     if (pipecmd_wait (p, &status) < 0)
         err ("%p: %S: wait on ssh cmd: %m\n", pipecmd_target (p));  
 
-    if (status != 0)
-        err ("%p: %s: ssh exited with exit code %d\n", 
-             pipecmd_target (p), WEXITSTATUS (status));
-
     pipecmd_destroy (p);
 
     return WEXITSTATUS (status);
