@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: xrcmd.c 1009 2006-02-14 16:11:43Z grondo $
+ *  $Id: xrcmd.c 1152 2008-01-29 17:50:41Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -213,6 +213,8 @@ xrcmd(char *ahost, char *addr, char *locuser, char *remuser,
     char c;
     struct xpollfd xpfds[2];
 
+    memset (xpfds, 0, sizeof (xpfds));
+
     pid = getpid();
 
     sigemptyset(&blockme);
@@ -229,6 +231,7 @@ xrcmd(char *ahost, char *addr, char *locuser, char *remuser,
             return (-1);
         }
         fcntl(s, F_SETOWN, pid);
+        memset (&sin, 0, sizeof (sin));
         sin.sin_family = AF_INET;
         memcpy(&sin.sin_addr, addr, IP_ADDR_LEN);
         sin.sin_port = htons(RSH_PORT);
