@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: dsh.c 1123 2007-05-07 16:44:53Z grondo $
+ *  $Id: dsh.c 1151 2008-01-29 17:45:54Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -538,7 +538,7 @@ static int _do_output (int fd, cbuf_t cb, out_f outf, bool read_rc, thd_t *t)
         if (read_rc)
             t->rc = _extract_rc (buf);
 
-        if ((buf != NULL) && (strlen (buf) > 0)) {
+        if (strlen (buf) > 0) {
             if (t->labels)
                 outf ("%S: %s", t->host, buf);
             else
@@ -638,6 +638,8 @@ static void *_rsh_thread(void *args)
 
         fd_set_nonblocking (a->rcmd->fd);
 
+        memset (xpfds, 0, sizeof (xpfds));
+
         /* prep for poll call */
         xpfds[0].fd = a->rcmd->fd;
         if (a->dsh_sopt) {      /* separate stderr */
