@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: dsh.h 1009 2006-02-14 16:11:43Z grondo $
+ *  $Id: dsh.h 1102 2006-12-07 23:44:25Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -51,7 +51,7 @@
 #define MAX_SP_NODE_NUMBER (MAX_SP_NODES * MAX_SP_NODES_PER_FRAME - 1)
 
 typedef enum { DSH_NEW, DSH_RCMD, DSH_READING, DSH_DONE,
-        DSH_FAILED } state_t;
+        DSH_FAILED, DSH_CANCELED } state_t;
 
 typedef struct thd {
     pthread_t thread;
@@ -74,7 +74,11 @@ typedef struct thd {
     char *pcp_outfile;          /* name of output file/dir */
     bool pcp_popt;              /* preserve mtime/mode */
     bool pcp_ropt;              /* recursive */
+    bool pcp_yopt;              /* target is directory */
+    bool pcp_Popt;              /* reverse copy */
+    bool pcp_Zopt;              /* pcp client */
     char *pcp_progname;         /* program name */
+    char *outfile_name;         /* outfile name */
     int rc;                     /* remote return code (-S) */
     int nodeid;                 /* node index */
     int nnodes;                 /* number of nodes in job */
