@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: opt.c 1156 2008-03-19 17:50:50Z grondo $
+ *  $Id: opt.c 1174 2008-11-25 21:17:05Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -75,7 +75,8 @@ Usage: pdsh [-options] command ...\n\
 #define OPT_USAGE_PCP "\
 Usage: pdcp [-options] src [src2...] dest\n\
 -r                recursively copy files\n\
--p                preserve modification time and modes\n"
+-p                preserve modification time and modes\n\
+-e PATH           specify the path to pdcp on the remote machine\n"
 /* undocumented "-y"  target must be directory option */
 /* undocumented "-z"  run pdcp server option */
 /* undocumented "-Z"  run pdcp client option */
@@ -112,8 +113,8 @@ Usage: rpdcp [-options] src [src2...] dir\n\
 #else
 #define DSH_ARGS    "S"
 #endif
-#define PCP_ARGS	"pryzZ"
-#define GEN_ARGS	"hLNKR:t:cqf:w:x:l:u:bI:deVT:Q"
+#define PCP_ARGS	"pryzZe:"
+#define GEN_ARGS	"hLNKR:t:cqf:w:x:l:u:bI:dVT:Q"
 
 /*
  *  Pdsh options string (for getopt) -- initialized
@@ -495,6 +496,14 @@ void opt_args(opt_t * opt, int argc, char *argv[])
             else
                 goto test_module_option;
             break;
+        case 'e':
+            if (pdsh_personality() == PCP) {
+                Free ((void **) &opt->path_progname);
+                opt->path_progname = Strdup(optarg);
+            } 
+            else
+                goto test_module_option;
+            break;
         case 'V':              /* show version */
             _show_version();
             break;
@@ -982,12 +991,23 @@ static int get_host_rcmd_type (char *hosts, char **rptr, char **hptr,
     if (p && q && p > q)
         errx ("Host spec \"%s\" not of form [rcmd_type:][user@]hosts\n", hosts);
 
-    if (p) {
+    /*
+     *  If we found a single ':' character, then everything
+     *   preceeding that is the rcmd type.  Otherwise, we ignore
+     *   presence of all colons. This can be done b/c even if there
+     *   were another colon later in the string, the string preceeding
+     *   it can not be an rcmd type since colon is not extant in rcmd
+     *   type names.
+     */
+    if (p && (*(p+1) != ':')) {
         *rptr = *hptr;
         *p++ = '\0';
         *hptr = p;
     }
 
+    /*
+     *  If we found a '@' char then what precedes it is username.
+     */
     if (q) {
         *uptr = *hptr;
         *q++ = '\0';
