@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: pcp_client.c 1141 2007-08-22 20:27:04Z achu $
+ *  $Id: pcp_client.c 1175 2008-11-25 21:17:07Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -371,7 +371,7 @@ static int _pcp_sendfile (struct pcp_filename *pf, struct pcp_client *pcp)
 			errx("%p: failed to send exit subdir flag\n");
 		if (pcp_response(pcp->infd, pcp->host) < 0)
 			errx("%p: failed to exit subdir properly\n");
-		return (-1);
+		return (0);
 	}
 
 	/* during a reverse copy, the hostname has to be attached
