@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: pcp_server.h 1009 2006-02-14 16:11:43Z grondo $
+ *  $Id: pcp_server.h 1102 2006-12-07 23:44:25Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -33,6 +33,14 @@
 
 #include "src/pdsh/opt.h"
 
-int pcp_server(opt_t *pdsh_opts);
+struct pcp_server {
+	int infd;
+	int outfd;
+	bool preserve;
+	bool target_is_dir;
+	char *outfile;
+};
+
+int pcp_server (struct pcp_server *s);
 
 #endif /* _PCP_SERVER_H */
