@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: wcoll.c 1009 2006-02-14 16:11:43Z grondo $
+ *  $Id: wcoll.c 1126 2007-06-06 16:16:10Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -73,7 +73,7 @@ hostlist_t read_wcoll(char *file, FILE * f)
             *p = '\0';
         xstrcln(buf, NULL);
 
-        if (hostlist_push(new, buf) == 0)
+        if ((buf[0] != '\0') && (hostlist_push(new, buf) == 0))
             err("%p: warning: target '%s' not parsed\n", buf);
     }
     if (f == NULL)
